<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Employee\Http\Requests\EmployeesRequest;
use Bixo\Employee\Interfaces\EmployeesRepositoryInterface;
use Bixo\Employee\Models\Employees;
use Bixo\Employee\Forms\Employees as Form;

/**
 * APIController  class for employees.
 */
class EmployeesAPIController extends BaseController
{

    /**
     * Initialize employees resource controller.
     *
     * @param type EmployeesRepositoryInterface $employees
     *
     * @return null
     */
    public function __construct(EmployeesRepositoryInterface $employees)
    {
        parent::__construct();
        $this->repository = $employees;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Employee\Repositories\Criteria\EmployeesResourceCriteria::class);
    }

    /**
     * Display a list of employees.
     *
     * @return Response
     */
    public function index(EmployeesRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Employee\Repositories\Presenter\EmployeesPresenter::class)
            ->paginate();
    }

    /**
     * Display employees.
     *
     * @param Request $request
     * @param Model   $employees
     *
     * @return Response
     */
    public function show(EmployeesRequest $request, Employees $employees)
    {
        return $employees->setPresenter(\Bixo\Employee\Repositories\Presenter\EmployeesListPresenter::class);
        ;
    }

    /**
     * Create new employees.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EmployeesRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('employee::employees.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('employee/employees/' . $employees->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/employees');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the employees.
     *
     * @param Request $request
     * @param Model   $employees
     *
     * @return Response
     */
    public function update(EmployeesRequest $request, Employees $employees)
    {
        try {
            $data = $request->all();

            $employees->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('employee::employees.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('employee/employees/' . $employees->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/employees/' . $employees->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the employees.
     *
     * @param Model   $employees
     *
     * @return Response
     */
    public function destroy(EmployeesRequest $request, Employees $employees)
    {
        try {
            $employees->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('employee::employees.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('employee/employees/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/employees/' . $employees->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
