<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Employee\Http\Requests\LeavesRequest;
use Bixo\Employee\Interfaces\LeavesRepositoryInterface;
use Bixo\Employee\Models\Leaves;
use Bixo\Employee\Forms\Leaves as Form;

/**
 * APIController  class for leaves.
 */
class LeavesAPIController extends BaseController
{

    /**
     * Initialize leaves resource controller.
     *
     * @param type LeavesRepositoryInterface $leaves
     *
     * @return null
     */
    public function __construct(LeavesRepositoryInterface $leaves)
    {
        parent::__construct();
        $this->repository = $leaves;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Employee\Repositories\Criteria\LeavesResourceCriteria::class);
    }

    /**
     * Display a list of leaves.
     *
     * @return Response
     */
    public function index(LeavesRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Employee\Repositories\Presenter\LeavesPresenter::class)
            ->paginate();
    }

    /**
     * Display leaves.
     *
     * @param Request $request
     * @param Model   $leaves
     *
     * @return Response
     */
    public function show(LeavesRequest $request, Leaves $leaves)
    {
        return $leaves->setPresenter(\Bixo\Employee\Repositories\Presenter\LeavesListPresenter::class);
        ;
    }

    /**
     * Create new leaves.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeavesRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('employee::leaves.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('employee/leaves/' . $leaves->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/leaves');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the leaves.
     *
     * @param Request $request
     * @param Model   $leaves
     *
     * @return Response
     */
    public function update(LeavesRequest $request, Leaves $leaves)
    {
        try {
            $data = $request->all();

            $leaves->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('employee::leaves.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('employee/leaves/' . $leaves->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/leaves/' . $leaves->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the leaves.
     *
     * @param Model   $leaves
     *
     * @return Response
     */
    public function destroy(LeavesRequest $request, Leaves $leaves)
    {
        try {
            $leaves->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('employee::leaves.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('employee/leaves/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('employee/leaves/' . $leaves->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
