<?php

namespace Bixo\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Employee\Models\Attendance;

class AttendancePolicy
{

    /**
     * Determine if the given user can view the attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function view(UserPolicy $user, Attendance $attendance)
    {
        if ($user->canDo('employee.attendance.view') && $user->isAdmin()) {
            return true;
        }

        return $attendance->user_id == user_id() && $attendance->user_type == user_type();
    }

    /**
     * Determine if the given user can create a attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.attendance.create');
    }

    /**
     * Determine if the given user can update the given attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function update(UserPolicy $user, Attendance $attendance)
    {
        if ($user->canDo('employee.attendance.edit') && $user->isAdmin()) {
            return true;
        }

        return $attendance->user_id == user_id() && $attendance->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Attendance $attendance)
    {
        return $attendance->user_id == user_id() && $attendance->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Attendance $attendance)
    {
        if ($user->canDo('employee.attendance.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attendance.
     *
     * @param UserPolicy $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Attendance $attendance)
    {
        if ($user->canDo('employee.attendance.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
