<?php

namespace Bixo\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Employee\Models\Benefits;

class BenefitsPolicy
{

    /**
     * Determine if the given user can view the benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function view(UserPolicy $user, Benefits $benefits)
    {
        if ($user->canDo('employee.benefits.view') && $user->isAdmin()) {
            return true;
        }

        return $benefits->user_id == user_id() && $benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can create a benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.benefits.create');
    }

    /**
     * Determine if the given user can update the given benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function update(UserPolicy $user, Benefits $benefits)
    {
        if ($user->canDo('employee.benefits.edit') && $user->isAdmin()) {
            return true;
        }

        return $benefits->user_id == user_id() && $benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Benefits $benefits)
    {
        return $benefits->user_id == user_id() && $benefits->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Benefits $benefits)
    {
        if ($user->canDo('employee.benefits.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given benefits.
     *
     * @param UserPolicy $user
     * @param Benefits $benefits
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Benefits $benefits)
    {
        if ($user->canDo('employee.benefits.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
