<?php

namespace Bixo\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Employee\Models\Leaves;

class LeavesPolicy
{

    /**
     * Determine if the given user can view the leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leaves $leaves)
    {
        if ($user->canDo('employee.leaves.view') && $user->isAdmin()) {
            return true;
        }

        return $leaves->user_id == user_id() && $leaves->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.leaves.create');
    }

    /**
     * Determine if the given user can update the given leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leaves $leaves)
    {
        if ($user->canDo('employee.leaves.edit') && $user->isAdmin()) {
            return true;
        }

        return $leaves->user_id == user_id() && $leaves->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leaves $leaves)
    {
        return $leaves->user_id == user_id() && $leaves->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leaves $leaves)
    {
        if ($user->canDo('employee.leaves.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leaves.
     *
     * @param UserPolicy $user
     * @param Leaves $leaves
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leaves $leaves)
    {
        if ($user->canDo('employee.leaves.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
