<?php

namespace Bixo\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Employee\Models\Newjoinee;

class NewjoineePolicy
{

    /**
     * Determine if the given user can view the newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function view(UserPolicy $user, Newjoinee $newjoinee)
    {
        if ($user->canDo('employee.newjoinee.view') && $user->isAdmin()) {
            return true;
        }

        return $newjoinee->user_id == user_id() && $newjoinee->user_type == user_type();
    }

    /**
     * Determine if the given user can create a newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.newjoinee.create');
    }

    /**
     * Determine if the given user can update the given newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function update(UserPolicy $user, Newjoinee $newjoinee)
    {
        if ($user->canDo('employee.newjoinee.edit') && $user->isAdmin()) {
            return true;
        }

        return $newjoinee->user_id == user_id() && $newjoinee->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Newjoinee $newjoinee)
    {
        return $newjoinee->user_id == user_id() && $newjoinee->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Newjoinee $newjoinee)
    {
        if ($user->canDo('employee.newjoinee.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given newjoinee.
     *
     * @param UserPolicy $user
     * @param Newjoinee $newjoinee
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Newjoinee $newjoinee)
    {
        if ($user->canDo('employee.newjoinee.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
