<?php

namespace Bixo\Employee\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Employee\Models\SalaryHistory;

class SalaryHistoryPolicy
{

    /**
     * Determine if the given user can view the salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function view(UserPolicy $user, SalaryHistory $salary_history)
    {
        if ($user->canDo('employee.salary_history.view') && $user->isAdmin()) {
            return true;
        }

        return $salary_history->user_id == user_id() && $salary_history->user_type == user_type();
    }

    /**
     * Determine if the given user can create a salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employee.salary_history.create');
    }

    /**
     * Determine if the given user can update the given salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function update(UserPolicy $user, SalaryHistory $salary_history)
    {
        if ($user->canDo('employee.salary_history.edit') && $user->isAdmin()) {
            return true;
        }

        return $salary_history->user_id == user_id() && $salary_history->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SalaryHistory $salary_history)
    {
        return $salary_history->user_id == user_id() && $salary_history->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SalaryHistory $salary_history)
    {
        if ($user->canDo('employee.salary_history.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given salary_history.
     *
     * @param UserPolicy $user
     * @param SalaryHistory $salary_history
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SalaryHistory $salary_history)
    {
        if ($user->canDo('employee.salary_history.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
