<?php

namespace Bixo\Employee\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Bixo\Employee\Models\Employee;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Employee\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/employee/employees/*')) {
            Route::bind('employees', function ($employees) {
                $employeesrepo = $this->app->make('Bixo\Employee\Interfaces\EmployeesRepositoryInterface');
                return $employeesrepo->findorNew($employees);
            });
        }
        if (Request::is('*/employee/benefits/*')) {
            Route::bind('benefits', function ($benefits) {
                $benefitsrepo = $this->app->make('Bixo\Employee\Interfaces\BenefitsRepositoryInterface');
                return $benefitsrepo->findorNew($benefits);
            });
        }
        if (Request::is('*/employee/dependents/*')) {
            Route::bind('dependents', function ($dependents) {
                $dependentsrepo = $this->app->make('Bixo\Employee\Interfaces\DependentsRepositoryInterface');
                return $dependentsrepo->findorNew($dependents);
            });
        }
        if (Request::is('*/employee/leaves/*')) {
            Route::bind('leaves', function ($leaves) {
                $leavesrepo = $this->app->make('Bixo\Employee\Interfaces\LeavesRepositoryInterface');
                return $leavesrepo->findorNew($leaves);
            });
        }
        if (Request::is('*/employee/salary_history/*')) {
            Route::bind('salary_history', function ($salary_history) {
                $salary_historyrepo = $this->app->make('Bixo\Employee\Interfaces\SalaryHistoryRepositoryInterface');
                return $salary_historyrepo->findorNew($salary_history);
            });
        }
        if (Request::is('*/employee/attendance/*')) {
            Route::bind('attendance', function ($attendance) {
                $attendancerepo = $this->app->make('Bixo\Employee\Interfaces\AttendanceRepositoryInterface');
                return $attendancerepo->findorNew($attendance);
            });
        }
        if (Request::is('*/employee/newjoinee/*')) {
            Route::bind('newjoinee', function ($newjoinee) {
                $newjoineerepo = $this->app->make('Bixo\Employee\Interfaces\NewjoineeRepositoryInterface');
                return $newjoineerepo->findorNew($newjoinee);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
